/**
 * @since 1.0.0
 */
import { type TextractClient, type TextractClientConfig, type AnalyzeDocumentCommandInput, type AnalyzeDocumentCommandOutput, type AnalyzeExpenseCommandInput, type AnalyzeExpenseCommandOutput, type AnalyzeIDCommandInput, type AnalyzeIDCommandOutput, type CreateAdapterCommandInput, type CreateAdapterCommandOutput, type CreateAdapterVersionCommandInput, type CreateAdapterVersionCommandOutput, type DeleteAdapterCommandInput, type DeleteAdapterCommandOutput, type DeleteAdapterVersionCommandInput, type DeleteAdapterVersionCommandOutput, type DetectDocumentTextCommandInput, type DetectDocumentTextCommandOutput, type GetAdapterCommandInput, type GetAdapterCommandOutput, type GetAdapterVersionCommandInput, type GetAdapterVersionCommandOutput, type GetDocumentAnalysisCommandInput, type GetDocumentAnalysisCommandOutput, type GetDocumentTextDetectionCommandInput, type GetDocumentTextDetectionCommandOutput, type GetExpenseAnalysisCommandInput, type GetExpenseAnalysisCommandOutput, type GetLendingAnalysisCommandInput, type GetLendingAnalysisCommandOutput, type GetLendingAnalysisSummaryCommandInput, type GetLendingAnalysisSummaryCommandOutput, type ListAdapterVersionsCommandInput, type ListAdapterVersionsCommandOutput, type ListAdaptersCommandInput, type ListAdaptersCommandOutput, type ListTagsForResourceCommandInput, type ListTagsForResourceCommandOutput, type StartDocumentAnalysisCommandInput, type StartDocumentAnalysisCommandOutput, type StartDocumentTextDetectionCommandInput, type StartDocumentTextDetectionCommandOutput, type StartExpenseAnalysisCommandInput, type StartExpenseAnalysisCommandOutput, type StartLendingAnalysisCommandInput, type StartLendingAnalysisCommandOutput, type TagResourceCommandInput, type TagResourceCommandOutput, type UntagResourceCommandInput, type UntagResourceCommandOutput, type UpdateAdapterCommandInput, type UpdateAdapterCommandOutput } from "@aws-sdk/client-textract";
import { Effect, Layer } from "effect";
import { AccessDeniedError, BadDocumentError, ConflictError, DocumentTooLargeError, HumanLoopQuotaExceededError, IdempotentParameterMismatchError, InternalServerError, InvalidJobIdError, InvalidKMSKeyError, InvalidParameterError, InvalidS3ObjectError, LimitExceededError, ProvisionedThroughputExceededError, ResourceNotFoundError, ServiceQuotaExceededError, ThrottlingError, UnsupportedDocumentError, ValidationError, SdkError } from "./Errors";
import { TextractClientInstance } from "./TextractClientInstance";
import { TextractClientInstanceConfig } from "./TextractClientInstanceConfig";
/**
 * @since 1.0.0
 */
export interface HttpHandlerOptions {
    /**
     * The maximum time in milliseconds that the connection phase of a request
     * may take before the connection attempt is abandoned.
     */
    requestTimeout?: number;
}
interface TextractService$ {
    readonly _: unique symbol;
    /**
     * @see {@link AnalyzeDocumentCommand}
     */
    analyzeDocument(args: AnalyzeDocumentCommandInput, options?: HttpHandlerOptions): Effect.Effect<AnalyzeDocumentCommandOutput, SdkError | AccessDeniedError | BadDocumentError | DocumentTooLargeError | HumanLoopQuotaExceededError | InternalServerError | InvalidParameterError | InvalidS3ObjectError | ProvisionedThroughputExceededError | ThrottlingError | UnsupportedDocumentError>;
    /**
     * @see {@link AnalyzeExpenseCommand}
     */
    analyzeExpense(args: AnalyzeExpenseCommandInput, options?: HttpHandlerOptions): Effect.Effect<AnalyzeExpenseCommandOutput, SdkError | AccessDeniedError | BadDocumentError | DocumentTooLargeError | InternalServerError | InvalidParameterError | InvalidS3ObjectError | ProvisionedThroughputExceededError | ThrottlingError | UnsupportedDocumentError>;
    /**
     * @see {@link AnalyzeIDCommand}
     */
    analyzeID(args: AnalyzeIDCommandInput, options?: HttpHandlerOptions): Effect.Effect<AnalyzeIDCommandOutput, SdkError | AccessDeniedError | BadDocumentError | DocumentTooLargeError | InternalServerError | InvalidParameterError | InvalidS3ObjectError | ProvisionedThroughputExceededError | ThrottlingError | UnsupportedDocumentError>;
    /**
     * @see {@link CreateAdapterCommand}
     */
    createAdapter(args: CreateAdapterCommandInput, options?: HttpHandlerOptions): Effect.Effect<CreateAdapterCommandOutput, SdkError | AccessDeniedError | ConflictError | IdempotentParameterMismatchError | InternalServerError | InvalidParameterError | LimitExceededError | ProvisionedThroughputExceededError | ServiceQuotaExceededError | ThrottlingError | ValidationError>;
    /**
     * @see {@link CreateAdapterVersionCommand}
     */
    createAdapterVersion(args: CreateAdapterVersionCommandInput, options?: HttpHandlerOptions): Effect.Effect<CreateAdapterVersionCommandOutput, SdkError | AccessDeniedError | ConflictError | IdempotentParameterMismatchError | InternalServerError | InvalidKMSKeyError | InvalidParameterError | InvalidS3ObjectError | LimitExceededError | ProvisionedThroughputExceededError | ResourceNotFoundError | ServiceQuotaExceededError | ThrottlingError | ValidationError>;
    /**
     * @see {@link DeleteAdapterCommand}
     */
    deleteAdapter(args: DeleteAdapterCommandInput, options?: HttpHandlerOptions): Effect.Effect<DeleteAdapterCommandOutput, SdkError | AccessDeniedError | ConflictError | InternalServerError | InvalidParameterError | ProvisionedThroughputExceededError | ResourceNotFoundError | ThrottlingError | ValidationError>;
    /**
     * @see {@link DeleteAdapterVersionCommand}
     */
    deleteAdapterVersion(args: DeleteAdapterVersionCommandInput, options?: HttpHandlerOptions): Effect.Effect<DeleteAdapterVersionCommandOutput, SdkError | AccessDeniedError | ConflictError | InternalServerError | InvalidParameterError | ProvisionedThroughputExceededError | ResourceNotFoundError | ThrottlingError | ValidationError>;
    /**
     * @see {@link DetectDocumentTextCommand}
     */
    detectDocumentText(args: DetectDocumentTextCommandInput, options?: HttpHandlerOptions): Effect.Effect<DetectDocumentTextCommandOutput, SdkError | AccessDeniedError | BadDocumentError | DocumentTooLargeError | InternalServerError | InvalidParameterError | InvalidS3ObjectError | ProvisionedThroughputExceededError | ThrottlingError | UnsupportedDocumentError>;
    /**
     * @see {@link GetAdapterCommand}
     */
    getAdapter(args: GetAdapterCommandInput, options?: HttpHandlerOptions): Effect.Effect<GetAdapterCommandOutput, SdkError | AccessDeniedError | InternalServerError | InvalidParameterError | ProvisionedThroughputExceededError | ResourceNotFoundError | ThrottlingError | ValidationError>;
    /**
     * @see {@link GetAdapterVersionCommand}
     */
    getAdapterVersion(args: GetAdapterVersionCommandInput, options?: HttpHandlerOptions): Effect.Effect<GetAdapterVersionCommandOutput, SdkError | AccessDeniedError | InternalServerError | InvalidParameterError | ProvisionedThroughputExceededError | ResourceNotFoundError | ThrottlingError | ValidationError>;
    /**
     * @see {@link GetDocumentAnalysisCommand}
     */
    getDocumentAnalysis(args: GetDocumentAnalysisCommandInput, options?: HttpHandlerOptions): Effect.Effect<GetDocumentAnalysisCommandOutput, SdkError | AccessDeniedError | InternalServerError | InvalidJobIdError | InvalidKMSKeyError | InvalidParameterError | InvalidS3ObjectError | ProvisionedThroughputExceededError | ThrottlingError>;
    /**
     * @see {@link GetDocumentTextDetectionCommand}
     */
    getDocumentTextDetection(args: GetDocumentTextDetectionCommandInput, options?: HttpHandlerOptions): Effect.Effect<GetDocumentTextDetectionCommandOutput, SdkError | AccessDeniedError | InternalServerError | InvalidJobIdError | InvalidKMSKeyError | InvalidParameterError | InvalidS3ObjectError | ProvisionedThroughputExceededError | ThrottlingError>;
    /**
     * @see {@link GetExpenseAnalysisCommand}
     */
    getExpenseAnalysis(args: GetExpenseAnalysisCommandInput, options?: HttpHandlerOptions): Effect.Effect<GetExpenseAnalysisCommandOutput, SdkError | AccessDeniedError | InternalServerError | InvalidJobIdError | InvalidKMSKeyError | InvalidParameterError | InvalidS3ObjectError | ProvisionedThroughputExceededError | ThrottlingError>;
    /**
     * @see {@link GetLendingAnalysisCommand}
     */
    getLendingAnalysis(args: GetLendingAnalysisCommandInput, options?: HttpHandlerOptions): Effect.Effect<GetLendingAnalysisCommandOutput, SdkError | AccessDeniedError | InternalServerError | InvalidJobIdError | InvalidKMSKeyError | InvalidParameterError | InvalidS3ObjectError | ProvisionedThroughputExceededError | ThrottlingError>;
    /**
     * @see {@link GetLendingAnalysisSummaryCommand}
     */
    getLendingAnalysisSummary(args: GetLendingAnalysisSummaryCommandInput, options?: HttpHandlerOptions): Effect.Effect<GetLendingAnalysisSummaryCommandOutput, SdkError | AccessDeniedError | InternalServerError | InvalidJobIdError | InvalidKMSKeyError | InvalidParameterError | InvalidS3ObjectError | ProvisionedThroughputExceededError | ThrottlingError>;
    /**
     * @see {@link ListAdapterVersionsCommand}
     */
    listAdapterVersions(args: ListAdapterVersionsCommandInput, options?: HttpHandlerOptions): Effect.Effect<ListAdapterVersionsCommandOutput, SdkError | AccessDeniedError | InternalServerError | InvalidParameterError | ProvisionedThroughputExceededError | ResourceNotFoundError | ThrottlingError | ValidationError>;
    /**
     * @see {@link ListAdaptersCommand}
     */
    listAdapters(args: ListAdaptersCommandInput, options?: HttpHandlerOptions): Effect.Effect<ListAdaptersCommandOutput, SdkError | AccessDeniedError | InternalServerError | InvalidParameterError | ProvisionedThroughputExceededError | ThrottlingError | ValidationError>;
    /**
     * @see {@link ListTagsForResourceCommand}
     */
    listTagsForResource(args: ListTagsForResourceCommandInput, options?: HttpHandlerOptions): Effect.Effect<ListTagsForResourceCommandOutput, SdkError | AccessDeniedError | InternalServerError | InvalidParameterError | ProvisionedThroughputExceededError | ResourceNotFoundError | ThrottlingError | ValidationError>;
    /**
     * @see {@link StartDocumentAnalysisCommand}
     */
    startDocumentAnalysis(args: StartDocumentAnalysisCommandInput, options?: HttpHandlerOptions): Effect.Effect<StartDocumentAnalysisCommandOutput, SdkError | AccessDeniedError | BadDocumentError | DocumentTooLargeError | IdempotentParameterMismatchError | InternalServerError | InvalidKMSKeyError | InvalidParameterError | InvalidS3ObjectError | LimitExceededError | ProvisionedThroughputExceededError | ThrottlingError | UnsupportedDocumentError>;
    /**
     * @see {@link StartDocumentTextDetectionCommand}
     */
    startDocumentTextDetection(args: StartDocumentTextDetectionCommandInput, options?: HttpHandlerOptions): Effect.Effect<StartDocumentTextDetectionCommandOutput, SdkError | AccessDeniedError | BadDocumentError | DocumentTooLargeError | IdempotentParameterMismatchError | InternalServerError | InvalidKMSKeyError | InvalidParameterError | InvalidS3ObjectError | LimitExceededError | ProvisionedThroughputExceededError | ThrottlingError | UnsupportedDocumentError>;
    /**
     * @see {@link StartExpenseAnalysisCommand}
     */
    startExpenseAnalysis(args: StartExpenseAnalysisCommandInput, options?: HttpHandlerOptions): Effect.Effect<StartExpenseAnalysisCommandOutput, SdkError | AccessDeniedError | BadDocumentError | DocumentTooLargeError | IdempotentParameterMismatchError | InternalServerError | InvalidKMSKeyError | InvalidParameterError | InvalidS3ObjectError | LimitExceededError | ProvisionedThroughputExceededError | ThrottlingError | UnsupportedDocumentError>;
    /**
     * @see {@link StartLendingAnalysisCommand}
     */
    startLendingAnalysis(args: StartLendingAnalysisCommandInput, options?: HttpHandlerOptions): Effect.Effect<StartLendingAnalysisCommandOutput, SdkError | AccessDeniedError | BadDocumentError | DocumentTooLargeError | IdempotentParameterMismatchError | InternalServerError | InvalidKMSKeyError | InvalidParameterError | InvalidS3ObjectError | LimitExceededError | ProvisionedThroughputExceededError | ThrottlingError | UnsupportedDocumentError>;
    /**
     * @see {@link TagResourceCommand}
     */
    tagResource(args: TagResourceCommandInput, options?: HttpHandlerOptions): Effect.Effect<TagResourceCommandOutput, SdkError | AccessDeniedError | InternalServerError | InvalidParameterError | ProvisionedThroughputExceededError | ResourceNotFoundError | ServiceQuotaExceededError | ThrottlingError | ValidationError>;
    /**
     * @see {@link UntagResourceCommand}
     */
    untagResource(args: UntagResourceCommandInput, options?: HttpHandlerOptions): Effect.Effect<UntagResourceCommandOutput, SdkError | AccessDeniedError | InternalServerError | InvalidParameterError | ProvisionedThroughputExceededError | ResourceNotFoundError | ThrottlingError | ValidationError>;
    /**
     * @see {@link UpdateAdapterCommand}
     */
    updateAdapter(args: UpdateAdapterCommandInput, options?: HttpHandlerOptions): Effect.Effect<UpdateAdapterCommandOutput, SdkError | AccessDeniedError | ConflictError | InternalServerError | InvalidParameterError | ProvisionedThroughputExceededError | ResourceNotFoundError | ThrottlingError | ValidationError>;
}
/**
 * @since 1.0.0
 * @category constructors
 */
export declare const makeTextractService: Effect.Effect<TextractService$, never, TextractClientInstance>;
declare const TextractService_base: import("effect/Context").TagClass<TextractService, "@effect-aws/client-textract/TextractService", TextractService$> & {
    readonly _: Effect.Effect<TextractService$["_"], never, TextractService>;
    analyzeDocument: (args: AnalyzeDocumentCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<AnalyzeDocumentCommandOutput, AccessDeniedError | BadDocumentError | DocumentTooLargeError | HumanLoopQuotaExceededError | InternalServerError | InvalidParameterError | InvalidS3ObjectError | ProvisionedThroughputExceededError | ThrottlingError | UnsupportedDocumentError | SdkError, TextractService>;
    analyzeExpense: (args: AnalyzeExpenseCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<AnalyzeExpenseCommandOutput, AccessDeniedError | BadDocumentError | DocumentTooLargeError | InternalServerError | InvalidParameterError | InvalidS3ObjectError | ProvisionedThroughputExceededError | ThrottlingError | UnsupportedDocumentError | SdkError, TextractService>;
    analyzeID: (args: AnalyzeIDCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<AnalyzeIDCommandOutput, AccessDeniedError | BadDocumentError | DocumentTooLargeError | InternalServerError | InvalidParameterError | InvalidS3ObjectError | ProvisionedThroughputExceededError | ThrottlingError | UnsupportedDocumentError | SdkError, TextractService>;
    createAdapter: (args: CreateAdapterCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<CreateAdapterCommandOutput, AccessDeniedError | ConflictError | IdempotentParameterMismatchError | InternalServerError | InvalidParameterError | LimitExceededError | ProvisionedThroughputExceededError | ServiceQuotaExceededError | ThrottlingError | ValidationError | SdkError, TextractService>;
    createAdapterVersion: (args: CreateAdapterVersionCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<CreateAdapterVersionCommandOutput, AccessDeniedError | ConflictError | IdempotentParameterMismatchError | InternalServerError | InvalidKMSKeyError | InvalidParameterError | InvalidS3ObjectError | LimitExceededError | ProvisionedThroughputExceededError | ResourceNotFoundError | ServiceQuotaExceededError | ThrottlingError | ValidationError | SdkError, TextractService>;
    deleteAdapter: (args: DeleteAdapterCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<DeleteAdapterCommandOutput, AccessDeniedError | ConflictError | InternalServerError | InvalidParameterError | ProvisionedThroughputExceededError | ResourceNotFoundError | ThrottlingError | ValidationError | SdkError, TextractService>;
    deleteAdapterVersion: (args: DeleteAdapterVersionCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<DeleteAdapterVersionCommandOutput, AccessDeniedError | ConflictError | InternalServerError | InvalidParameterError | ProvisionedThroughputExceededError | ResourceNotFoundError | ThrottlingError | ValidationError | SdkError, TextractService>;
    detectDocumentText: (args: DetectDocumentTextCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<DetectDocumentTextCommandOutput, AccessDeniedError | BadDocumentError | DocumentTooLargeError | InternalServerError | InvalidParameterError | InvalidS3ObjectError | ProvisionedThroughputExceededError | ThrottlingError | UnsupportedDocumentError | SdkError, TextractService>;
    getAdapter: (args: GetAdapterCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<GetAdapterCommandOutput, AccessDeniedError | InternalServerError | InvalidParameterError | ProvisionedThroughputExceededError | ResourceNotFoundError | ThrottlingError | ValidationError | SdkError, TextractService>;
    getAdapterVersion: (args: GetAdapterVersionCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<GetAdapterVersionCommandOutput, AccessDeniedError | InternalServerError | InvalidParameterError | ProvisionedThroughputExceededError | ResourceNotFoundError | ThrottlingError | ValidationError | SdkError, TextractService>;
    getDocumentAnalysis: (args: GetDocumentAnalysisCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<GetDocumentAnalysisCommandOutput, AccessDeniedError | InternalServerError | InvalidJobIdError | InvalidKMSKeyError | InvalidParameterError | InvalidS3ObjectError | ProvisionedThroughputExceededError | ThrottlingError | SdkError, TextractService>;
    getDocumentTextDetection: (args: GetDocumentTextDetectionCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<GetDocumentTextDetectionCommandOutput, AccessDeniedError | InternalServerError | InvalidJobIdError | InvalidKMSKeyError | InvalidParameterError | InvalidS3ObjectError | ProvisionedThroughputExceededError | ThrottlingError | SdkError, TextractService>;
    getExpenseAnalysis: (args: GetExpenseAnalysisCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<GetExpenseAnalysisCommandOutput, AccessDeniedError | InternalServerError | InvalidJobIdError | InvalidKMSKeyError | InvalidParameterError | InvalidS3ObjectError | ProvisionedThroughputExceededError | ThrottlingError | SdkError, TextractService>;
    getLendingAnalysis: (args: GetLendingAnalysisCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<GetLendingAnalysisCommandOutput, AccessDeniedError | InternalServerError | InvalidJobIdError | InvalidKMSKeyError | InvalidParameterError | InvalidS3ObjectError | ProvisionedThroughputExceededError | ThrottlingError | SdkError, TextractService>;
    getLendingAnalysisSummary: (args: GetLendingAnalysisSummaryCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<GetLendingAnalysisSummaryCommandOutput, AccessDeniedError | InternalServerError | InvalidJobIdError | InvalidKMSKeyError | InvalidParameterError | InvalidS3ObjectError | ProvisionedThroughputExceededError | ThrottlingError | SdkError, TextractService>;
    listAdapterVersions: (args: ListAdapterVersionsCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<ListAdapterVersionsCommandOutput, AccessDeniedError | InternalServerError | InvalidParameterError | ProvisionedThroughputExceededError | ResourceNotFoundError | ThrottlingError | ValidationError | SdkError, TextractService>;
    listAdapters: (args: ListAdaptersCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<ListAdaptersCommandOutput, AccessDeniedError | InternalServerError | InvalidParameterError | ProvisionedThroughputExceededError | ThrottlingError | ValidationError | SdkError, TextractService>;
    listTagsForResource: (args: ListTagsForResourceCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<ListTagsForResourceCommandOutput, AccessDeniedError | InternalServerError | InvalidParameterError | ProvisionedThroughputExceededError | ResourceNotFoundError | ThrottlingError | ValidationError | SdkError, TextractService>;
    startDocumentAnalysis: (args: StartDocumentAnalysisCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<StartDocumentAnalysisCommandOutput, AccessDeniedError | BadDocumentError | DocumentTooLargeError | IdempotentParameterMismatchError | InternalServerError | InvalidKMSKeyError | InvalidParameterError | InvalidS3ObjectError | LimitExceededError | ProvisionedThroughputExceededError | ThrottlingError | UnsupportedDocumentError | SdkError, TextractService>;
    startDocumentTextDetection: (args: StartDocumentTextDetectionCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<StartDocumentTextDetectionCommandOutput, AccessDeniedError | BadDocumentError | DocumentTooLargeError | IdempotentParameterMismatchError | InternalServerError | InvalidKMSKeyError | InvalidParameterError | InvalidS3ObjectError | LimitExceededError | ProvisionedThroughputExceededError | ThrottlingError | UnsupportedDocumentError | SdkError, TextractService>;
    startExpenseAnalysis: (args: StartExpenseAnalysisCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<StartExpenseAnalysisCommandOutput, AccessDeniedError | BadDocumentError | DocumentTooLargeError | IdempotentParameterMismatchError | InternalServerError | InvalidKMSKeyError | InvalidParameterError | InvalidS3ObjectError | LimitExceededError | ProvisionedThroughputExceededError | ThrottlingError | UnsupportedDocumentError | SdkError, TextractService>;
    startLendingAnalysis: (args: StartLendingAnalysisCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<StartLendingAnalysisCommandOutput, AccessDeniedError | BadDocumentError | DocumentTooLargeError | IdempotentParameterMismatchError | InternalServerError | InvalidKMSKeyError | InvalidParameterError | InvalidS3ObjectError | LimitExceededError | ProvisionedThroughputExceededError | ThrottlingError | UnsupportedDocumentError | SdkError, TextractService>;
    tagResource: (args: TagResourceCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<TagResourceCommandOutput, AccessDeniedError | InternalServerError | InvalidParameterError | ProvisionedThroughputExceededError | ResourceNotFoundError | ServiceQuotaExceededError | ThrottlingError | ValidationError | SdkError, TextractService>;
    untagResource: (args: UntagResourceCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<UntagResourceCommandOutput, AccessDeniedError | InternalServerError | InvalidParameterError | ProvisionedThroughputExceededError | ResourceNotFoundError | ThrottlingError | ValidationError | SdkError, TextractService>;
    updateAdapter: (args: UpdateAdapterCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<UpdateAdapterCommandOutput, AccessDeniedError | ConflictError | InternalServerError | InvalidParameterError | ProvisionedThroughputExceededError | ResourceNotFoundError | ThrottlingError | ValidationError | SdkError, TextractService>;
} & {
    use: <X>(body: (_: TextractService$) => X) => X extends Effect.Effect<infer A, infer E, infer R> ? Effect.Effect<A, E, R | TextractService> : Effect.Effect<X, never, TextractService>;
};
/**
 * @since 1.0.0
 * @category models
 */
export declare class TextractService extends TextractService_base {
    static readonly defaultLayer: Layer.Layer<TextractService, never, never>;
    static readonly layer: (config: TextractClientConfig) => Layer.Layer<TextractService, never, never>;
    static readonly baseLayer: (evaluate: (defaultConfig: TextractClientConfig) => TextractClient) => Layer.Layer<TextractService, never, never>;
}
/**
 * @since 1.0.0
 * @category models
 * @alias TextractService
 */
export declare const Textract: typeof TextractService;
/**
 * @since 1.0.0
 * @category layers
 * @deprecated use Textract.baseLayer instead
 */
export declare const BaseTextractServiceLayer: Layer.Layer<TextractService, never, TextractClientInstance>;
/**
 * @since 1.0.0
 * @category layers
 * @deprecated use Textract.layer instead
 */
export declare const TextractServiceLayer: Layer.Layer<TextractService, never, TextractClientInstanceConfig>;
/**
 * @since 1.0.0
 * @category layers
 * @deprecated use Textract.defaultLayer instead
 */
export declare const DefaultTextractServiceLayer: Layer.Layer<TextractService, never, never>;
export {};
